// src/plugin.ts
import { normalizePath } from "vite";
import path from "path";
import ftpDeploy from "ftp-deploy";
function vitePluginFtp(userConfig = {}) {
  let outDir = "dist";
  const options = {
    host: "",
    port: 21,
    remoteDir: "",
    user: "root",
    password: "",
    include: ["*", "**/*"],
    waitingTime: 2e3
  };
  Object.assign(options, userConfig);
  if (Object.keys(options).some((key) => !options[key])) {
    console.log("Error: invalid config, please check carefully");
    process.exit(1);
  }
  return {
    name: "vite-plugin-ftp",
    apply: "build",
    enforce: "post",
    configResolved(config) {
      outDir = config.build.outDir;
    },
    async closeBundle() {
      const ora = await import("ora").then((res) => res.default);
      const chalk = await import("chalk").then((res) => res.default);
      const spinner = ora();
      const ftp = new ftpDeploy();
      try {
        options.localRoot = path.resolve(normalizePath(outDir));
        ftp.on("uploading", function(data) {
          const { totalFilesCount, transferredFileCount, filename } = data;
          spinner.start(
            `uploading ${transferredFileCount}/${totalFilesCount} ${filename}`
          );
        });
        console.log(chalk.cyan(`\u2728 begin upload ${options.remoteDir}`));
        await new Promise(
          (resolve) => setTimeout(() => {
            resolve(true);
          }, options.waitingTime)
        );
        await ftp.deploy({
          host: options.host,
          port: options.port,
          user: options.user,
          password: options.password,
          localRoot: options.localRoot,
          remoteRoot: options.remoteDir,
          include: options.include
        }).then(() => spinner.succeed(`upload complete`)).catch((err) => {
          console.log(err);
          spinner.info("upload fail");
          process.exit(1);
        });
      } catch (error) {
        spinner.fail(
          `${chalk.yellow("Client connect fail, Please check config carefully")}`
        );
        process.exit(1);
      } finally {
        return;
      }
    }
  };
}

// src/index.ts
var src_default = vitePluginFtp;
export {
  src_default as default,
  vitePluginFtp
};
